==> 2025-11-13-11-48-27-dify-1.9.2.zip: dify-1.9.2/web/i18n/fa-IR/plugin.ts <==
const translation = {
  category: {
    all: 'همه',
    models: 'مدل',
    bundles: 'بسته',
    agents: 'استراتژی های عامل',
    tools: 'ابزار',
    extensions: 'پسوند',
    datasources: 'منابع داده',
  },
  categorySingle: {
    tool: 'ابزار',
    agent: 'استراتژی نمایندگی',
    extension: 'فرمت',
    model: 'مدل',
    bundle: 'بسته',
    datasource: 'منبع داده',
  },
  list: {
    source: {
      marketplace: 'از Marketplace نصب کنید',
      github: 'نصب از GitHub',
      local: 'نصب از فایل بسته محلی',
    },
    notFound: 'هیچ افزونه ای یافت نشد',
    noInstalled: 'هیچ افزونه ای نصب نشده است',
  },
  source: {
    github: 'گیت‌هاب',
    marketplace: 'بازار',
    local: 'فایل بسته محلی',
  },
  detailPanel: {
    categoryTip: {
      debugging: 'اشکال زدایی پلاگین',
      marketplace: 'نصب شده از Marketplace',
      local: 'پلاگین محلی',
      github: 'نصب شده از Github',
    },
    operation: {
      checkUpdate: 'به روز رسانی را بررسی کنید',
      info: 'اطلاعات پلاگین',
      remove: 'حذف',
      update: 'روز رسانی',
      detail: 'جزئیات',
      viewDetail: 'نمایش جزئیات',
      install: 'نصب',
    },
    toolSelector: {
      descriptionPlaceholder:
        'شرح مختصری از هدف ابزار، به عنوان مثال، دما را برای یک مکان خاص دریافت کنید.',
      auto: 'خودکار',
      unsupportedContent: 'نسخه افزونه نصب شده این عمل را ارائه نمی دهد.',
      paramsTip1: 'پارامترهای استنتاج LLM را کنترل می کند.',
      params: 'پیکربندی استدلال',
      placeholder: 'یک ابزار را انتخاب کنید...',
      paramsTip2: 'وقتی «خودکار» خاموش باشد، از مقدار پیش فرض استفاده می شود.',
      descriptionLabel: 'توضیحات ابزار',
      title: 'ابزار افزودن',
      settings: 'تنظیمات کاربر',
      empty:
        'برای افزودن ابزارها روی دکمه "+" کلیک کنید. می توانید چندین ابزار اضافه کنید.',
      toolLabel: 'ابزار',
      uninstalledTitle: 'ابزار نصب نشده است',
      uninstalledLink: 'مدیریت در پلاگین ها',
      uninstalledContent:
        'این افزونه از مخزن local/GitHub نصب شده است. لطفا پس از نصب استفاده کنید.',
      unsupportedTitle: 'اکشن پشتیبانی نشده',
      unsupportedContent2: 'برای تغییر نسخه کلیک کنید.',
      toolSetting: 'تنظیمات ابزار',
      unsupportedMCPTool:
        'نسخه فعلی پلاگین استراتژی عامل انتخاب‌شده از ابزارهای MCP پشتیبانی نمی‌کند.',
    },
    endpointDeleteTip: 'حذف نقطه پایانی',
    disabled: 'غیر فعال',
    strategyNum: '{{عدد}} {{استراتژی}} شامل',
    configureApp: 'پیکربندی اپلیکیشن',
    endpoints: 'نقاط پایانی',
    endpointsDocLink: 'مشاهده سند',
    actionNum: '{{عدد}} {{اقدام}} شامل',
    endpointDisableContent: 'آیا می خواهید {{name}} را غیرفعال کنید؟',
    endpointModalTitle: 'راه اندازی اندپوینت',
    endpointsTip:
      'این افزونه عملکردهای خاصی را از طریق نقاط پایانی ارائه می دهد و می توانید چندین مجموعه نقطه پایانی را برای فضای کاری فعلی پیکربندی کنید.',
    serviceOk: 'خدمات خوب',
    modelNum: '{{عدد}} مدل های گنجانده شده است',
    endpointDisableTip: 'غیرفعال کردن نقطه پایانی',
    configureModel: 'مدل را پیکربندی کنید',
    configureTool: 'ابزار پیکربندی',
    endpointsEmpty: 'برای افزودن نقطه پایانی روی دکمه "+" کلیک کنید',
    endpointModalDesc:
      'پس از پیکربندی، می توان از ویژگی های ارائه شده توسط افزونه از طریق نقاط پایانی API استفاده کرد.',
    switchVersion: 'نسخه سوئیچ',
    endpointDeleteContent: 'آیا می خواهید {{name}} را حذف کنید؟',
    deprecation: {
      reason: {
        ownershipTransferred: 'مالکیت منتقل شد',
        businessAdjustments: 'تنظیمات کسب و کار',
        noMaintainer: 'بدون نگهدارنده',
      },
      noReason: 'این افزونه منسوخ شده است و دیگر به روز رسانی نخواهد شد.',
      onlyReason:
        'این افزونه به دلیل {{deprecatedReason}} منسوخ شده و دیگر به‌روزرسانی نخواهد شد.',
      fullMessage:
        'این افزونه به دلیل {{deprecatedReason}} منسوخ شده است و دیگر به‌روزرسانی نخواهد شد. لطفا به‌جای آن از <CustomLink href=\'https://example.com/\'>{{-alternativePluginId}}</CustomLink> استفاده کنید.',
    },
  },
  debugInfo: {
    title: 'اشکال زدایی',
    viewDocs: 'مشاهده اسناد',
  },
  privilege: {
    everyone: 'همه',
    admins: 'مدیران',
    whoCanInstall: 'چه کسی می تواند افزونه ها را نصب و مدیریت کند؟',
    title: 'تنظیمات پلاگین',
    noone: 'هیچ',
    whoCanDebug: 'چه کسی می تواند افزونه ها را اشکال زدایی کند؟',
  },
  pluginInfoModal: {
    repository: 'مخزن',
    packageName: 'بسته',
    title: 'اطلاعات پلاگین',
    release: 'انتشار',
  },
  action: {
    pluginInfo: 'اطلاعات پلاگین',
    usedInApps: 'این افزونه در برنامه های {{num}} استفاده می شود.',
    deleteContentLeft: 'آیا می خواهید',
    checkForUpdates: 'بررسی به روزرسانی ها',
    delete: 'حذف افزونه',
    deleteContentRight: 'افزونه?',
  },
  installModal: {
    labels: {
      package: 'بسته',
      version: 'نسخهٔ',
      repository: 'مخزن',
    },
    back: 'بازگشت',
    next: 'بعدی',
    cancel: 'لغو',
    uploadingPackage: 'آپلود {{packageName}}...',
    fromTrustSource:
      'لطفا مطمئن شوید که افزونه ها را فقط از <trustSource>یک منبع قابل اعتماد</trustSource> نصب می کنید.',
    readyToInstall: 'در مورد نصب افزونه زیر',
    install: 'نصب',
    pluginLoadError: 'خطای بارگذاری افزونه',
    pluginLoadErrorDesc: 'این افزونه نصب نخواهد شد',
    close: 'نزدیک',
    installFailed: 'نصب ناموفق بود',
    installFailedDesc: 'افزونه نصب شده است ناموفق است.',
    installedSuccessfullyDesc: 'این افزونه با موفقیت نصب شد.',
    dropPluginToInstall: 'بسته افزونه را برای نصب اینجا رها کنید',
    installing: 'نصب...',
    readyToInstallPackage: 'در مورد نصب افزونه زیر',
    readyToInstallPackages: 'در شرف نصب افزونه های {{num}} زیر',
    installedSuccessfully: 'نصب موفقیت آمیز بود',
    installPlugin: 'افزونه را نصب کنید',
    installComplete: 'نصب کامل شد',
    uploadFailed: 'آپلود انجام نشد',
    installWarning: 'این افزونه اجازه نصب ندارد.',
  },
  installFromGitHub: {
    installPlugin: 'افزونه را از GitHub نصب کنید',
    selectPackagePlaceholder: 'لطفا یک بسته را انتخاب کنید',
    gitHubRepo: 'مخزن GitHub',
    updatePlugin: 'افزونه را از GitHub به روز کنید',
    uploadFailed: 'آپلود انجام نشد',
    installedSuccessfully: 'نصب موفقیت آمیز بود',
    installNote:
      'لطفا مطمئن شوید که افزونه ها را فقط از یک منبع قابل اعتماد نصب می کنید.',
    installFailed: 'نصب ناموفق بود',
    selectVersionPlaceholder: 'لطفا یک نسخه را انتخاب کنید',
    selectPackage: 'بسته را انتخاب کنید',
    selectVersion: 'انتخاب نسخه',
  },
  upgrade: {
    usedInApps: 'استفاده شده در برنامه های {{num}}',
    successfulTitle: 'نصب موفقیت آمیز',
    close: 'نزدیک',
    title: 'افزونه را نصب کنید',
    upgrading: 'نصب...',
    upgrade: 'نصب',
    description: 'در مورد نصب افزونه زیر',
  },
  error: {
    noReleasesFound:
      'هیچ نسخه ای یافت نشد. لطفا مخزن GitHub یا URL ورودی را بررسی کنید.',
    inValidGitHubUrl:
      'URL GitHub نامعتبر است. لطفا یک URL معتبر را در قالب وارد کنید: https://github.com/owner/repo',
    fetchReleasesError:
      'امکان بازیابی نسخه ها وجود ندارد. لطفا بعدا دوباره امتحان کنید.',
  },
  marketplace: {
    sortOption: {
      firstReleased: 'اولین منتشر شد',
      recentlyUpdated: 'اخیرا به روز شده است',
      mostPopular: 'محبوب ترین',
      newlyReleased: 'تازه منتشر شده',
    },
    and: 'و',
    viewMore: 'بیشتر ببینید',
    moreFrom: 'اطلاعات بیشتر از Marketplace',
    pluginsResult: 'نتایج {{num}}',
    noPluginFound: 'هیچ افزونه ای یافت نشد',
    sortBy: 'شهر سیاه',
    difyMarketplace: 'بازار دیفی',
    empower: 'توسعه هوش مصنوعی خود را توانمند کنید',
    discover: 'کشف',
    verifiedTip: 'تأیید شده توسط دیفی',
    partnerTip: 'تأیید شده توسط یک شریک دیفی',
  },
  task: {
    installing: 'نصب پلاگین های {{installingLength}}، 0 انجام شد.',
    clearAll: 'پاک کردن همه',
    installedError: 'افزونه های {{errorLength}} نصب نشدند',
    installError: 'پلاگین های {{errorLength}} نصب نشدند، برای مشاهده کلیک کنید',
    installingWithSuccess:
      'نصب پلاگین های {{installingLength}}، {{successLength}} موفقیت آمیز است.',
    installingWithError:
      'نصب پلاگین های {{installingLength}}، {{successLength}} با موفقیت مواجه شد، {{errorLength}} ناموفق بود',
  },
  searchTools: 'ابزارهای جستجو...',
  findMoreInMarketplace: 'اطلاعات بیشتر در Marketplace',
  searchInMarketplace: 'جستجو در Marketplace',
  searchCategories: 'دسته بندی ها را جستجو کنید',
  fromMarketplace: 'از بازار',
  installPlugin: 'افزونه را نصب کنید',
  from: 'از',
  install: '{{num}} نصب می شود',
  endpointsEnabled: '{{num}} مجموعه نقاط پایانی فعال شده است',
  searchPlugins: 'جستجوی افزونه ها',
  installFrom: 'نصب از',
  installAction: 'نصب',
  allCategories: 'همه دسته بندی ها',
  search: 'جستجو',
  metadata: {
    title: 'پلاگین ها',
  },
  difyVersionNotCompatible:
    'نسخه فعلی دیفی با این پلاگین سازگار نیست، لطفاً به نسخه حداقل مورد نیاز به‌روزرسانی کنید: {{minimalDifyVersion}}',
  requestAPlugin: 'درخواست یک افزونه',
  publishPlugins: 'انتشار افزونه ها',
  auth: {
    useOAuthAuth: 'از مجوز OAuth استفاده کنید',
    oauthClient: 'کلاینت اوتور',
    custom: 'سفارشی',
    addOAuth: 'OAuth اضافه کنید',
    workspaceDefault: 'پیش فرض محیط کار',
    authorization: 'مجوز',
    default: 'پیش‌فرض',
    setupOAuth: 'راه‌اندازی کلاینت OAuth',
    useOAuth: 'از OAuth استفاده کنید',
    setDefault: 'به عنوان پیش‌فرض تنظیم شود',
    useApi: 'از کلید API استفاده کنید',
    useApiAuth: 'پیکربندی مجوز کلید API',
    authRemoved: 'منبع حذف شد',
    authorizations: 'مجوزها',
    authorizationName: 'نام مجوز',
    addApi: 'کلید API را اضافه کنید',
    saveAndAuth: 'ذخیره و تأیید',
    saveOnly: 'فقط ذخیره کنید',
    oauthClientSettings: 'تنظیمات کلاینت اوتور',
    clientInfo:
      'از آنجایی که هیچ راز مشتری سیستم برای این ارائه‌دهنده ابزار پیدا نشد، تنظیم دستی آن ضروری است، لطفاً برای redirect_uri از',
    useApiAuthDesc:
      'پس از پیکربندی اعتبارنامه‌ها، تمامی اعضای درون فضای کاری می‌توانند از این ابزار هنگام نظم‌دهی به برنامه‌ها استفاده کنند.',
    unavailable: 'در دسترس نیست',
    credentialUnavailable:
      'دسترسی به مدارک در حال حاضر امکان‌پذیر نیست. لطفاً با مدیر تماس بگیرید.',
    customCredentialUnavailable:
      'اعتبارنامه‌های سفارشی در حال حاضر در دسترس نیستند',
    credentialUnavailableInButton: 'گواهی در دسترس نیست',
    connectedWorkspace: 'فضای کاری متصل',
    emptyAuth: 'لطفا احراز هویت را پیکربندی کنید',
  },
  deprecated: 'منسوخ شده',
  autoUpdate: {
    strategy: {
      disabled: {
        name: 'ناتوان',
        description: 'پلاگین‌ها به‌طور خودکار به‌روزرسانی نخواهند شد',
      },
      fixOnly: {
        name: 'فقط تعمیر کنید',
        selectedDescription: 'به‌روزرسانی خودکار تنها برای نسخه‌های وصله',
        description:
          'به‌روزرسانی خودکار فقط برای نسخه‌های پچ (مانند ۱.۰.۱ → ۱.۰.۲). تغییرات جزئی نسخه باعث راه‌اندازی به‌روزرسانی‌ها نمی‌شود.',
      },
      latest: {
        name: 'جدیدترین',
        selectedDescription: 'همیشه به آخرین نسخه بروزرسانی کنید',
        description: 'همیشه به آخرین نسخه بروزرسانی کنید',
      },
    },
    upgradeMode: {
      all: 'همه را بروزرسانی کن',
      partial: 'فقط انتخاب شده',
      exclude: 'انتخاب شده را استثنا کن',
    },
    upgradeModePlaceholder: {
      exclude: 'افزونه‌های انتخاب شده به‌صورت خودکار به‌روزرسانی نخواهند شد',
      partial:
        'فقط پلاگین‌های انتخاب شده به‌روزرسانی خودکار خواهند داشت. در حال حاضر هیچ پلاگینی انتخاب نشده است، بنابراین هیچ پلاگینی به‌روزرسانی خودکار نخواهد شد.',
    },
    operation: {
      select: 'افزونه‌ها را انتخاب کنید',
      clearAll: 'همه را پاک کن',
    },
    pluginDowngradeWarning: {
      title: 'کاهش نسخه افزونه',
      downgrade: 'به هر حال تنزل دهید',
      exclude: 'از بروزرسانی خودکار مستثنی شود',
      description:
        'به‌روزرسانی خودکار برای این افزونه در حال حاضر فعال است. کاهش نسخه ممکن است باعث شود تغییرات شما در حین به‌روزرسانی خودکار بعدی نادیده گرفته شود.',
    },
    noPluginPlaceholder: {
      noFound: 'هیچ افزونه‌ای یافت نشد',
      noInstalled: 'هیچ افزونه‌ای نصب نشده است',
    },
    updateTimeTitle: 'زمان به‌روزرسانی',
    specifyPluginsToUpdate: 'ماژول‌هایی را برای به‌روزرسانی مشخص کنید',
    updateTime: 'زمان به‌روزرسانی',
    automaticUpdates: 'بروز رسانی خودکار',
    updateSettings: 'تنظیمات را به‌روزرسانی کنید',
    changeTimezone:
      'برای تغییر منطقه زمانی، به <setTimezone>تنظیمات</setTimezone> بروید',
    excludeUpdate:
      'پلاگین‌های زیر {{num}} به‌طور خودکار به‌روزرسانی نخواهند شد',
    nextUpdateTime: 'به‌روزرسانی خودکار بعدی: {{time}}',
    partialUPdate:
      'تنها {{num}} پلاگین زیر به‌طور خودکار به‌روزرسانی خواهد شد.',
  },
}

export default translation

==> 2025-11-24-10-54-20-dify-1.1.3.zip: dify-1.1.3/web/i18n/fa-IR/plugin.ts <==
const translation = {
  category: {
    all: 'همه',
    models: 'مدل',
    bundles: 'بسته',
    agents: 'استراتژی های عامل',
    tools: 'ابزار',
    extensions: 'پسوند',
  },
  categorySingle: {
    tool: 'ابزار',
    agent: 'استراتژی نمایندگی',
    extension: 'فرمت',
    model: 'مدل',
    bundle: 'بسته',
  },
  list: {
    source: {
      marketplace: 'از Marketplace نصب کنید',
      github: 'نصب از GitHub',
      local: 'نصب از فایل بسته محلی',
    },
    notFound: 'هیچ افزونه ای یافت نشد',
    noInstalled: 'هیچ افزونه ای نصب نشده است',
  },
  source: {
    github: 'گیت‌هاب',
    marketplace: 'بازار',
    local: 'فایل بسته محلی',
  },
  detailPanel: {
    categoryTip: {
      debugging: 'اشکال زدایی پلاگین',
      marketplace: 'نصب شده از Marketplace',
      local: 'پلاگین محلی',
      github: 'نصب شده از Github',
    },
    operation: {
      checkUpdate: 'به روز رسانی را بررسی کنید',
      info: 'اطلاعات پلاگین',
      remove: 'حذف',
      update: 'روز رسانی',
      detail: 'جزئیات',
      viewDetail: 'نمایش جزئیات',
      install: 'نصب',
    },
    toolSelector: {
      descriptionPlaceholder: 'شرح مختصری از هدف ابزار، به عنوان مثال، دما را برای یک مکان خاص دریافت کنید.',
      auto: 'خودکار',
      unsupportedContent: 'نسخه افزونه نصب شده این عمل را ارائه نمی دهد.',
      paramsTip1: 'پارامترهای استنتاج LLM را کنترل می کند.',
      params: 'پیکربندی استدلال',
      placeholder: 'یک ابزار را انتخاب کنید...',
      paramsTip2: 'وقتی «خودکار» خاموش باشد، از مقدار پیش فرض استفاده می شود.',
      descriptionLabel: 'توضیحات ابزار',
      title: 'ابزار افزودن',
      settings: 'تنظیمات کاربر',
      empty: 'برای افزودن ابزارها روی دکمه "+" کلیک کنید. می توانید چندین ابزار اضافه کنید.',
      toolLabel: 'ابزار',
      uninstalledTitle: 'ابزار نصب نشده است',
      uninstalledLink: 'مدیریت در پلاگین ها',
      uninstalledContent: 'این افزونه از مخزن local/GitHub نصب شده است. لطفا پس از نصب استفاده کنید.',
      unsupportedTitle: 'اکشن پشتیبانی نشده',
      unsupportedContent2: 'برای تغییر نسخه کلیک کنید.',
    },
    endpointDeleteTip: 'حذف نقطه پایانی',
    disabled: 'غیر فعال',
    strategyNum: '{{عدد}} {{استراتژی}} شامل',
    configureApp: 'پیکربندی اپلیکیشن',
    endpoints: 'نقاط پایانی',
    endpointsDocLink: 'مشاهده سند',
    actionNum: '{{عدد}} {{اقدام}} شامل',
    endpointDisableContent: 'آیا می خواهید {{name}} را غیرفعال کنید؟',
    endpointModalTitle: 'راه اندازی اندپوینت',
    endpointsTip: 'این افزونه عملکردهای خاصی را از طریق نقاط پایانی ارائه می دهد و می توانید چندین مجموعه نقطه پایانی را برای فضای کاری فعلی پیکربندی کنید.',
    serviceOk: 'خدمات خوب',
    modelNum: '{{عدد}} مدل های گنجانده شده است',
    endpointDisableTip: 'غیرفعال کردن نقطه پایانی',
    configureModel: 'مدل را پیکربندی کنید',
    configureTool: 'ابزار پیکربندی',
    endpointsEmpty: 'برای افزودن نقطه پایانی روی دکمه "+" کلیک کنید',
    endpointModalDesc: 'پس از پیکربندی، می توان از ویژگی های ارائه شده توسط افزونه از طریق نقاط پایانی API استفاده کرد.',
    switchVersion: 'نسخه سوئیچ',
    endpointDeleteContent: 'آیا می خواهید {{name}} را حذف کنید؟',
  },
  debugInfo: {
    title: 'اشکال زدایی',
    viewDocs: 'مشاهده اسناد',
  },
  privilege: {
    everyone: 'همه',
    admins: 'مدیران',
    whoCanInstall: 'چه کسی می تواند افزونه ها را نصب و مدیریت کند؟',
    title: 'تنظیمات پلاگین',
    noone: 'هیچ',
    whoCanDebug: 'چه کسی می تواند افزونه ها را اشکال زدایی کند؟',
  },
  pluginInfoModal: {
    repository: 'مخزن',
    packageName: 'بسته',
    title: 'اطلاعات پلاگین',
    release: 'انتشار',
  },
  action: {
    pluginInfo: 'اطلاعات پلاگین',
    usedInApps: 'این افزونه در برنامه های {{num}} استفاده می شود.',
    deleteContentLeft: 'آیا می خواهید',
    checkForUpdates: 'بررسی به روزرسانی ها',
    delete: 'حذف افزونه',
    deleteContentRight: 'افزونه?',
  },
  installModal: {
    labels: {
      package: 'بسته',
      version: 'نسخهٔ',
      repository: 'مخزن',
    },
    back: 'بازگشت',
    next: 'بعدی',
    cancel: 'لغو',
    uploadingPackage: 'آپلود {{packageName}}...',
    fromTrustSource: 'لطفا مطمئن شوید که افزونه ها را فقط از <trustSource>یک منبع قابل اعتماد</trustSource> نصب می کنید.',
    readyToInstall: 'در مورد نصب افزونه زیر',
    install: 'نصب',
    pluginLoadError: 'خطای بارگذاری افزونه',
    pluginLoadErrorDesc: 'این افزونه نصب نخواهد شد',
    close: 'نزدیک',
    installFailed: 'نصب ناموفق بود',
    installFailedDesc: 'افزونه نصب شده است ناموفق است.',
    installedSuccessfullyDesc: 'این افزونه با موفقیت نصب شد.',
    dropPluginToInstall: 'بسته افزونه را برای نصب اینجا رها کنید',
    installing: 'نصب...',
    readyToInstallPackage: 'در مورد نصب افزونه زیر',
    readyToInstallPackages: 'در شرف نصب افزونه های {{num}} زیر',
    installedSuccessfully: 'نصب موفقیت آمیز بود',
    installPlugin: 'افزونه را نصب کنید',
    installComplete: 'نصب کامل شد',
    uploadFailed: 'آپلود انجام نشد',
  },
  installFromGitHub: {
    installPlugin: 'افزونه را از GitHub نصب کنید',
    selectPackagePlaceholder: 'لطفا یک بسته را انتخاب کنید',
    gitHubRepo: 'مخزن GitHub',
    updatePlugin: 'افزونه را از GitHub به روز کنید',
    uploadFailed: 'آپلود انجام نشد',
    installedSuccessfully: 'نصب موفقیت آمیز بود',
    installNote: 'لطفا مطمئن شوید که افزونه ها را فقط از یک منبع قابل اعتماد نصب می کنید.',
    installFailed: 'نصب ناموفق بود',
    selectVersionPlaceholder: 'لطفا یک نسخه را انتخاب کنید',
    selectPackage: 'بسته را انتخاب کنید',
    selectVersion: 'انتخاب نسخه',
  },
  upgrade: {
    usedInApps: 'استفاده شده در برنامه های {{num}}',
    successfulTitle: 'نصب موفقیت آمیز',
    close: 'نزدیک',
    title: 'افزونه را نصب کنید',
    upgrading: 'نصب...',
    upgrade: 'نصب',
    description: 'در مورد نصب افزونه زیر',
  },
  error: {
    noReleasesFound: 'هیچ نسخه ای یافت نشد. لطفا مخزن GitHub یا URL ورودی را بررسی کنید.',
    inValidGitHubUrl: 'URL GitHub نامعتبر است. لطفا یک URL معتبر را در قالب وارد کنید: https://github.com/owner/repo',
    fetchReleasesError: 'امکان بازیابی نسخه ها وجود ندارد. لطفا بعدا دوباره امتحان کنید.',
  },
  marketplace: {
    sortOption: {
      firstReleased: 'اولین منتشر شد',
      recentlyUpdated: 'اخیرا به روز شده است',
      mostPopular: 'محبوب ترین',
      newlyReleased: 'تازه منتشر شده',
    },
    and: 'و',
    viewMore: 'بیشتر ببینید',
    moreFrom: 'اطلاعات بیشتر از Marketplace',
    pluginsResult: 'نتایج {{num}}',
    noPluginFound: 'هیچ افزونه ای یافت نشد',
    sortBy: 'شهر سیاه',
    difyMarketplace: 'بازار دیفی',
    empower: 'توسعه هوش مصنوعی خود را توانمند کنید',
    discover: 'کشف',
  },
  task: {
    installing: 'نصب پلاگین های {{installingLength}}، 0 انجام شد.',
    clearAll: 'پاک کردن همه',
    installedError: 'افزونه های {{errorLength}} نصب نشدند',
    installError: 'پلاگین های {{errorLength}} نصب نشدند، برای مشاهده کلیک کنید',
    installingWithSuccess: 'نصب پلاگین های {{installingLength}}، {{successLength}} موفقیت آمیز است.',
    installingWithError: 'نصب پلاگین های {{installingLength}}، {{successLength}} با موفقیت مواجه شد، {{errorLength}} ناموفق بود',
  },
  searchTools: 'ابزارهای جستجو...',
  findMoreInMarketplace: 'اطلاعات بیشتر در Marketplace',
  searchInMarketplace: 'جستجو در Marketplace',
  submitPlugin: 'ارسال افزونه',
  searchCategories: 'دسته بندی ها را جستجو کنید',
  fromMarketplace: 'از بازار',
  installPlugin: 'افزونه را نصب کنید',
  from: 'از',
  install: '{{num}} نصب می شود',
  endpointsEnabled: '{{num}} مجموعه نقاط پایانی فعال شده است',
  searchPlugins: 'جستجوی افزونه ها',
  installFrom: 'نصب از',
  installAction: 'نصب',
  allCategories: 'همه دسته بندی ها',
  search: 'جستجو',
}

export default translation
